@@ -1,3 +1,7 @@
+import numpy as np
+from matplotlib import GridSpec
+from matplotlib import pyplot as plt
+
 def plot_inverse_mapping(reducer,umap_df):
     def find_nearest_color(embedding, test_coord, umap_df, threshold_dist=0.8):
         x_array, y_array = embedding[:,0], embedding[:,1]
